@@ -7,7 +7,7 @@
 //   Emil Beinroth <emilbeinroth@gmx.net>
 //   Martin Väth <martin@mvath.de>
 
-#include <config.h>
+#include <config.h>  // IWYU pragma: keep
 
 #include <unistd.h>
 
@@ -44,6 +44,8 @@
 #include "main/main.h"
 #include "output/formatstring-print.h"
 #include "output/formatstring.h"
+#include "output/print-formats.h"
+#include "output/print-proto.h"
 #include "output/print-xml.h"
 #include "portage/basicversion.h"
 #include "portage/conf/portagesettings.h"
@@ -145,12 +147,14 @@ static void dump_help() {
 "         --ansi             reset the ansi 256 color palette\n"
 "     -n, --nocolor          do not use ANSI color codes\n"
 "     -F, --force-color      force colorful output\n"
+"         --color            color always/never/auto\n"
 "     -*, --pure-packages    Omit printing of overlay names and package number\n"
 "     -#, --only-names       --pure-packages with format <category>/<name>\n"
 "     -0  --brief (toggle)   Print at most one package then stop. See -q\n"
 "                            Usually faster with COUNT_ONLY_PRINTED=false\n"
 "         --brief2 (toggle)  Print at most two packages then stop\n"
 "     --xml (toggle)         output results in XML format\n"
+"     --proto (toggle)       output results in protobuf format\n"
 "     -c, --compact          compact search results\n"
 "     -v, --verbose          verbose search results\n"
 "     -N, --normal           ignores -c, -v, and DEFAULT_FORMAT\n"
@@ -225,12 +229,25 @@ static void dump_help() {
 "    -s, --name              name (default)\n"
 "    -H, --homepage          homepage\n"
 "    -L, --license           license\n"
-"    --deps                  same as --depend --rdepend --pdepend --hdepend\n"
-"    --depend                depend (needs DEP=true)\n"
-"    --rdepend               rdepend (needs DEP=true)\n"
-"    --pdepend               pdepend (needs DEP=true)\n"
-"    --hdepend               hdepend (needs DEP=true)\n"
+"    --deps                  same as --available-deps --installed-deps\n"
+"    --depend                same as --available-depend --installed-depend\n"
+"    --rdepend               same as --available-rdepend --installed-rdepend\n"
+"    --pdepend               same as --available-pdepend --installed-pdepend\n"
+"    --bdepend               same as --available-bdepend --installed-bdepend\n"
+"    --available-deps        same as --available-depend --available-rdepend\n"
+"                            --available-pdepend --available-bdepend\n"
+"    --available-depend      depend (of available version; only if DEP=true)\n"
+"    --available-rdepend     rdepend (of available version; only if DEP=true)\n"
+"    --available-pdepend     pdepend (of available version; only if DEP=true)\n"
+"    --available-bdepend     bdepend (of available version; only if DEP=true)\n"
+"    --installed-deps        same as --installed-depend --installed-rdepend\n"
+"                            --installed-pdepend --installed-bdepend\n"
+"    --installed-depend      depend (of installed version)\n"
+"    --installed-rdepend     rdepend (of installed version)\n"
+"    --installed-pdepend     pdepend (of installed version)\n"
+"    --installed-bdepend     bdepend (of installed version)\n"
 "    --set                   local package set name\n"
+"    --src-uri               SRC_URI\n"
 "    --eapi                  EAPI\n"
 "    --installed-eapi        EAPI of installed version\n"
 "    --slot                  slot\n"
@@ -261,6 +278,7 @@ static void dump_help() {
 static const char *formatstring;
 static const char *eix_cachefile(NULLPTR);
 static const char *var_to_print(NULLPTR);
+static const char *color(NULLPTR);
 
 enum OverlayMode {
 	mode_list_used_renumbered  = 0,
@@ -310,6 +328,7 @@ static struct LocalOptions {
 		dump_defaults,
 		known_vars,
 		xml,
+		proto,
 		test_unused,
 		do_debug,
 		ignore_etc_portage,
@@ -355,6 +374,7 @@ EixOptionList::EixOptionList() {
 
 	push_back(Option("nocolor",       'n',     Option::BOOLEAN_T,     &format->no_color));
 	push_back(Option("force-color",   'F',     Option::BOOLEAN_F,     &format->no_color));
+	push_back(Option("color",         O_COLOR, Option::STRING,        &color));
 	push_back(Option("versionlines",  'l',     Option::BOOLEAN,       &format->style_version_lines));
 	push_back(Option("versionsort",   'x',     Option::BOOLEAN,       &format->slot_sorted));
 	push_back(Option("pure-packages", '*',     Option::BOOLEAN,       &rc_options.pure_packages));
@@ -366,6 +386,7 @@ EixOptionList::EixOptionList() {
 	push_back(Option("compact",       'c',     Option::BOOLEAN_T,     &rc_options.compact_output));
 	push_back(Option("normal",        'N',     Option::BOOLEAN_T,     &rc_options.normal_output));
 	push_back(Option("xml",           O_XML,   Option::BOOLEAN,       &rc_options.xml));
+	push_back(Option("proto",         O_PROTO, Option::BOOLEAN,       &rc_options.proto));
 	push_back(Option("help",          'h',     Option::BOOLEAN_T,     &rc_options.show_help));
 	push_back(Option("version",       'V',     Option::BOOLEAN_T,     &rc_options.show_version));
 	push_back(Option("dump",          O_DUMP,  Option::BOOLEAN_T,     &rc_options.dump_eixrc));
@@ -468,6 +489,7 @@ EixOptionList::EixOptionList() {
 	// What to match in this criterion
 	push_back(Option("any",           'y'));
 	push_back(Option("name",          's'));
+	push_back(Option("src-uri",       O_SEARCH_SRC_URI));
 	push_back(Option("eapi",          O_SEARCH_EAPI));
 	push_back(Option("installed-eapi", O_SEARCH_INST_EAPI));
 	push_back(Option("slot",          O_SEARCH_SLOT));
@@ -483,7 +505,17 @@ EixOptionList::EixOptionList() {
 	push_back(Option("depend",        O_DEPEND));
 	push_back(Option("rdepend",       O_RDEPEND));
 	push_back(Option("pdepend",       O_PDEPEND));
-	push_back(Option("hdepend",       O_HDEPEND));
+	push_back(Option("bdepend",       O_BDEPEND));
+	push_back(Option("available-deps",    O_AVAILABLE_DEPS));
+	push_back(Option("available-depend",  O_AVAILABLE_DEPEND));
+	push_back(Option("available-rdepend", O_AVAILABLE_RDEPEND));
+	push_back(Option("available-pdepend", O_AVAILABLE_PDEPEND));
+	push_back(Option("available-bdepend", O_AVAILABLE_BDEPEND));
+	push_back(Option("installed-deps",    O_INSTALLED_DEPS));
+	push_back(Option("installed-depend",  O_INSTALLED_DEPEND));
+	push_back(Option("installed-rdepend", O_INSTALLED_RDEPEND));
+	push_back(Option("installed-pdepend", O_INSTALLED_PDEPEND));
+	push_back(Option("installed-bdepend", O_INSTALLED_BDEPEND));
 	push_back(Option("set",           O_SEARCH_SET));
 	push_back(Option("use",           'U'));
 	push_back(Option("installed-with-use",    O_INSTALLED_WITH_USE));
@@ -504,8 +536,9 @@ static void setup_defaults(EixRc *rc, bool is_tty) {
 	// Setup defaults
 	std::memset(&rc_options, 0, sizeof(rc_options));
 
-	Depend::use_depend         = rc->getBool("DEP");
-	Version::use_required_use  = rc->getBool("REQUIRED_USE");
+	Depend::use_depend           = rc->getBool("DEP");
+	Version::use_required_use    = rc->getBool("REQUIRED_USE");
+	ExtendedVersion::use_src_uri = rc->getBool("SRC_URI");
 
 	rc_options.quick           = rc->getBool("QUICKMODE");
 	rc_options.be_quiet        = rc->getBool("QUIETMODE");
@@ -636,6 +669,14 @@ int run_eix(int argc, char** argv) {
 	// Read our options from the commandline.
 	ArgumentReader argreader(argc, argv, EixOptionList());
 
+	if(unlikely(color != NULLPTR)) {
+		if(unlikely(strncasecmp("au", color, 2) == 0)) {
+			format->no_color = !is_tty;
+		} else {
+			format->no_color = !EixRc::istrue(color);
+		}
+	}
+
 	if(unlikely(rc_options.ansi)) {
 		AnsiColor::AnsiPalette();
 	}
@@ -737,7 +778,7 @@ int run_eix(int argc, char** argv) {
 
 	bool only_printed;
 
-	if(unlikely(rc_options.xml)) {
+	if(unlikely(rc_options.xml || rc_options.proto)) {
 		rc_options.pure_packages = format->no_color = true;
 		only_printed = false;
 	} else {
@@ -960,15 +1001,25 @@ int run_eix(int argc, char** argv) {
 	PrintFormat::OverlayUsed overlay_used(header.countOverlays(), false);
 	format->set_overlay_used(&overlay_used, &need_overlay_table);
 	PackageList::size_type count(0);
-	PrintXml *print_xml(NULLPTR);
-	if(rc_options.xml || rc_options.be_quiet) {
+	PrintFormats *print_formats(NULLPTR);
+	if(rc_options.xml || rc_options.proto || rc_options.be_quiet) {
 		overlay_mode = mode_list_none;
 		rc_options.pure_packages = true;
 	}
-	if(rc_options.xml && !matches.empty()) {
-		print_xml = new PrintXml(&header, &varpkg_db, format, &stability, &eixrc,
-			portagesettings["PORTDIR"]);
-		print_xml->start();
+	if (!matches.empty()) {
+		if(rc_options.xml) {
+			if (unlikely(rc_options.proto)) {
+				eix::say_error(_("--xml and --proto must not be specified simultaneously"));
+				std::exit(EXIT_FAILURE);
+			}
+			print_formats = new PrintXml(&header, &varpkg_db, format, &stability, &eixrc,
+				portagesettings["PORTDIR"]);
+		} else if (rc_options.proto) {
+			print_formats = new PrintProto(&header, &varpkg_db, format, &stability);
+		}
+		if (print_formats != NULLPTR) {
+			print_formats->start();
+		}
 	}
 	bool have_printed(false);
 	bool reached_limit(false), over_limit(false);
@@ -978,8 +1029,8 @@ int run_eix(int argc, char** argv) {
 		likely(it != matches.end()); ++it) {
 		stability.set_stability(*it);
 
-		if(unlikely(rc_options.xml)) {
-			print_xml->package(*it);
+		if(unlikely(print_formats != NULLPTR)) {
+			print_formats->package(*it);
 			continue;
 		}
 
@@ -1054,9 +1105,9 @@ int run_eix(int argc, char** argv) {
 			printed_overlay = have_printed = true;
 		}
 	}
-	if(unlikely(print_xml != NULLPTR)) {
-		print_xml->finish();
-		delete print_xml;
+	if(unlikely(print_formats != NULLPTR)) {
+		print_formats->finish();
+		delete print_formats;
 	}
 
 	if(!only_printed) {
