@@ -10,11 +10,11 @@
 #ifndef SRC_EIXTK_STRINGUTILS_H_
 #define SRC_EIXTK_STRINGUTILS_H_
 
-#include <config.h>
+#include <config.h>  // IWYU pragma: keep
 
 #include <locale>
 
-#include <cstdlib>
+#include <cstdlib>  // IWYU pragma: keep  // std::strtoll std::atoi etc.
 
 #include <map>
 #include <set>
@@ -468,7 +468,7 @@ class StringHash : public WordVec {
 
 	private:
 		bool hashing, finalized;
-		typedef std::map<std::string, StringHash::size_type> StrSizeMap;
+		typedef UNORDERED_MAP<std::string, StringHash::size_type> StrSizeMap;
 		StrSizeMap str_map;
 		static StringHash *comparison_this;
 		static bool frequency_comparison(const std::string a, const std::string b);
