@@ -8,7 +8,7 @@
 //   Martin Väth <martin@mvath.de>
 
 #include "eixTk/varsreader.h"
-#include <config.h>
+#include <config.h>  // IWYU pragma: keep
 
 #include <fcntl.h>
 #include <sys/mman.h>
@@ -169,14 +169,13 @@ void VarsReader::ASSIGN_KEY_VALUE() {
 			STOP;
 		}
 	} else if(unlikely( (parse_flags & ONLY_KEYWORDS_SLOT) )) {
+		(*vars)[string(key_begin, key_len)] = value;
 		if(unlikely(std::strncmp("KEYWORDS=", key_begin, 9) == 0)) {
-			(*vars)[string(key_begin, key_len)] = value;
 			parse_flags |= KEYWORDS_READ;
 			if(parse_flags & SLOT_READ) {
 				STOP;
 			}
 		} else if(unlikely(std::strncmp("SLOT=", key_begin, 5) == 0)) {
-			(*vars)[string(key_begin, key_len)] = value;
 			parse_flags |= SLOT_READ;
 			if(parse_flags & KEYWORDS_READ) {
 				STOP;
@@ -1173,6 +1172,9 @@ settings (except for APPEND_VALUES),
 adding variables and changed HAVE_READ to current instance.
 **/
 bool VarsReader::source(const string& filename, string *errtext) {
+	if(filename.empty()) {
+		return false;
+	}
 	VarsReader includefile((parse_flags & (~APPEND_VALUES)) | INTO_MAP);
 	includefile.accumulatingKeys(incremental_keys);
 	includefile.useMap(vars);
@@ -1186,6 +1188,18 @@ bool VarsReader::source(const string& filename, string *errtext) {
 				currprefix = it->second;
 		}
 	}
+	if(filename[0] != '/') {
+		const char *last_slash = std::strrchr(file_name, '/');
+		if(last_slash == NULLPTR) {
+			if(currprefix.empty() || (currprefix[currprefix.size() - 1] != '/')) {
+				currprefix.append(1, '/');
+			}
+		} else {
+GCC_DIAG_OFF(sign-conversion)
+			currprefix.assign(file_name, (last_slash - file_name) + 1);
+GCC_DIAG_ON(sign-conversion)
+		}
+	}
 	bool rvalue(includefile.read((currprefix + filename).c_str(), errtext, false, sourced_files));
 	parse_flags |= (includefile.parse_flags & HAVE_READ);
 	return rvalue;
