@@ -8,7 +8,7 @@
 //   Martin Väth <martin@mvath.de>
 
 #include "portage/conf/portagesettings.h"
-#include <config.h>
+#include <config.h>  // IWYU pragma: keep
 
 #include <cstdlib>
 #include <cstring>
@@ -76,7 +76,7 @@ bool PortageSettings::grab_setmasks(const char *file, SetsIndex i, WordVec *cont
 	if(!pushback_lines(file, &lines, recursive)) {
 		return false;
 	}
-	for(LineVec::iterator it(lines.begin()); likely(it < lines.end()); ++it) {
+	for(LineVec::iterator it(lines.begin()); likely(it != lines.end()); ++it) {
 		if(it->empty()) {
 			continue;
 		}
@@ -233,9 +233,15 @@ void PortageSettings::init(EixRc *eixrc, const ParseError *e, bool getlocal, boo
 			const char *s = repositories.c_str();
 			have_repos = reposfile.readmem(s, s + repositories.size(), NULLPTR);
 		} else {
-			have_repos = reposfile.read((*eixrc)["PORTAGE_REPOS_CONF"].c_str(), NULLPTR, true);
-			if(reposfile.read((m_eprefixconf + USER_REPOS_CONF).c_str(), NULLPTR, true)) {
+			string errtext;
+			have_repos = reposfile.read((*eixrc)["PORTAGE_REPOS_CONF"].c_str(), &errtext, true);
+			if(!have_repos) {
+				eix::say_error(_("error: %s")) % errtext;
+			}
+			if(reposfile.read((m_eprefixconf + USER_REPOS_CONF).c_str(), &errtext, true)) {
 				have_repos = true;
+			} else {
+				eix::say_error(_("error: %s")) % errtext;
 			}
 		}
 		const string *main_repo(NULLPTR);
@@ -262,7 +268,7 @@ void PortageSettings::init(EixRc *eixrc, const ParseError *e, bool getlocal, boo
 			}
 		}
 		if(portdirref.empty()) {
-			portdirref = "/usr/portage";
+			portdirref = PORTDIR_DEFAULT;
 		}
 		/* Normalize "PORTDIR": */
 		portdirref = normalize_path((m_eprefixportdir + portdirref).c_str(), true, true);
@@ -352,11 +358,10 @@ void PortageSettings::init(EixRc *eixrc, const ParseError *e, bool getlocal, boo
 			delete local_profile;
 			local_profile = NULLPTR;
 		}
-		profile->readremoveFiles();
 	} else {
 		profile->readMakeDefaults();
-		profile->readremoveFiles();
 	} {
+		profile->readremoveFiles();
 		const char *useflags(cstr("USE"));
 		if(likely(useflags != NULLPTR)) {
 			(*this)["USE.profile"] = useflags;
@@ -454,7 +459,7 @@ GCC_DIAG_ON(sign-conversion)
 	}
 	// Now finally read the local sets:
 	read_local_sets(sets_dirs);
-}
+}  // NOLINT(readability/fn_size)
 
 PortageSettings::~PortageSettings() {
 	delete profile;
