@@ -8,7 +8,7 @@
 //   Martin Väth <martin@mvath.de>
 
 #include "search/packagetest.h"
-#include <config.h>
+#include <config.h>  // IWYU pragma: keep
 
 #include <string>
 
@@ -51,16 +51,28 @@ const PackageTest::MatchField
 		PackageTest::IUSE,
 		PackageTest::USE_ENABLED,
 		PackageTest::USE_DISABLED,
+		PackageTest::SRC_URI,
 		PackageTest::EAPI,
+		PackageTest::INST_EAPI,
 		PackageTest::SLOT,
 		PackageTest::FULLSLOT,
 		PackageTest::INST_SLOT,
 		PackageTest::INST_FULLSLOT,
 		PackageTest::SET,
+		PackageTest::DEPENDA,
+		PackageTest::RDEPENDA,
+		PackageTest::PDEPENDA,
+		PackageTest::BDEPENDA,
+		PackageTest::DEPENDI,
+		PackageTest::RDEPENDI,
+		PackageTest::PDEPENDI,
+		PackageTest::BDEPENDI,
 		PackageTest::DEPEND,
 		PackageTest::RDEPEND,
 		PackageTest::PDEPEND,
-		PackageTest::HDEPEND,
+		PackageTest::BDEPEND,
+		PackageTest::DEPSA,
+		PackageTest::DEPSI,
 		PackageTest::DEPS,
 		PackageTest::ANY;
 
@@ -125,7 +137,7 @@ PackageTest::~PackageTest() {
 
 void PackageTest::calculateNeeds() {
 	need = PackageReader::NONE;
-	if((field & (EAPI | SLOT | FULLSLOT | SET)) != NONE) {
+	if((field & (SRC_URI | EAPI | SLOT | FULLSLOT | SET)) != NONE) {
 		setNeeds(PackageReader::VERSIONS);
 	}
 	if((field & HOMEPAGE) != NONE) {
@@ -143,16 +155,16 @@ void PackageTest::calculateNeeds() {
 	if((field & (NAME | CATEGORY_NAME)) != NONE) {
 		setNeeds(PackageReader::NAME);
 	}
-	if((field & (USE_ENABLED | USE_DISABLED | INST_EAPI | INST_SLOT | INST_FULLSLOT)) != NONE) {
+	if((field & (USE_ENABLED | USE_DISABLED | INST_EAPI | INST_SLOT | INST_FULLSLOT | DEPSI)) != NONE) {
 		setNeeds(PackageReader::NAME);
 	}
 	if(installed) {
 		setNeeds(PackageReader::NAME);
 	}
 	if(!Depend::use_depend) {
-		field &= ~DEPS;
+		field &= ~DEPSA;
 	}
-	if(((field & (IUSE | DEPS)) != NONE)  ||
+	if(((field & (IUSE | DEPSA)) != NONE) ||
 		dup_packages || dup_versions || slotted ||
 		upgrade || overlay || obsolete ||
 		world || worldset ||
@@ -192,6 +204,14 @@ bool PackageTest::stringMatch(Package *pkg) const {
 		return true;
 	}
 
+	if((field & SRC_URI) != NONE) {
+		for(Package::iterator it(pkg->begin());
+			likely(it != pkg->end()); ++it) {
+			if((*algorithm)(it->src_uri.c_str(), pkg))
+				return true;
+		}
+	}
+
 	if((field & EAPI) != NONE) {
 		for(Package::iterator it(pkg->begin());
 			likely(it != pkg->end()); ++it) {
@@ -225,18 +245,18 @@ bool PackageTest::stringMatch(Package *pkg) const {
 		}
 	}
 
-	if((field & DEPS) != NONE) {
-		bool depend((field & DEPEND) != NONE);
-		bool rdepend((field & RDEPEND) != NONE);
-		bool pdepend((field & PDEPEND) != NONE);
-		bool hdepend((field & HDEPEND) != NONE);
+	if((field & DEPSA) != NONE) {
+		bool depend((field & DEPENDA) != NONE);
+		bool rdepend((field & RDEPENDA) != NONE);
+		bool pdepend((field & PDEPENDA) != NONE);
+		bool bdepend((field & BDEPENDA) != NONE);
 		for(Package::iterator it(pkg->begin());
 			likely(it != pkg->end()); ++it) {
 			const Depend &dep(it->depend);
 			if((depend && (*algorithm)(dep.get_depend().c_str(), pkg))
 			|| (rdepend && (*algorithm)(dep.get_rdepend().c_str(), pkg))
 			|| (pdepend && (*algorithm)(dep.get_pdepend().c_str(), pkg))
-			|| (hdepend && (*algorithm)(dep.get_hdepend().c_str(), pkg))) {
+			|| (bdepend && (*algorithm)(dep.get_bdepend().c_str(), pkg))) {
 				return true;
 			}
 		}
@@ -254,7 +274,7 @@ bool PackageTest::stringMatch(Package *pkg) const {
 		}
 	}
 
-	if((field & (USE_ENABLED | USE_DISABLED | INST_EAPI | INST_SLOT | INST_FULLSLOT | DEPS)) == NONE) {
+	if((field & (USE_ENABLED | USE_DISABLED | INST_EAPI | INST_SLOT | INST_FULLSLOT | DEPSI)) == NONE) {
 		return false;
 	}
 
@@ -320,11 +340,11 @@ bool PackageTest::stringMatch(Package *pkg) const {
 		}
 	}
 
-	if((field & DEPS) != NONE) {
-		bool depend((field & DEPEND) != NONE);
-		bool rdepend((field & RDEPEND) != NONE);
-		bool pdepend((field & PDEPEND) != NONE);
-		bool hdepend((field & HDEPEND) != NONE);
+	if((field & DEPSI) != NONE) {
+		bool depend((field & DEPENDI) != NONE);
+		bool rdepend((field & RDEPENDI) != NONE);
+		bool pdepend((field & PDEPENDI) != NONE);
+		bool bdepend((field & BDEPENDI) != NONE);
 		for(InstVec::iterator it(installed_versions->begin());
 			it != installed_versions->end(); ++it) {
 			vardbpkg->readDepend(*pkg, &(*it), *header);
@@ -341,8 +361,8 @@ bool PackageTest::stringMatch(Package *pkg) const {
 				if((*algorithm)(dep.get_pdepend().c_str(), pkg))
 				return true;
 			}
-			if(hdepend) {
-				if((*algorithm)(dep.get_hdepend().c_str(), pkg))
+			if(bdepend) {
+				if((*algorithm)(dep.get_bdepend().c_str(), pkg))
 				return true;
 			}
 		}
