@@ -8,7 +8,7 @@
 //   Martin Väth <martin@mvath.de>
 
 #include "various/cli.h"
-#include <config.h>
+#include <config.h>  // IWYU pragma: keep
 
 #include <iostream>
 #include <string>
@@ -429,15 +429,48 @@ void parse_cli(MatchTree *matchtree, EixRc *eixrc, VarDbPkg *varpkg_db, PortageS
 			case O_PDEPEND: USE_TEST;
 				*test |= PackageTest::PDEPEND;
 				break;
-			case O_HDEPEND: USE_TEST;
-				*test |= PackageTest::HDEPEND;
+			case O_BDEPEND: USE_TEST;
+				*test |= PackageTest::BDEPEND;
 				break;
 			case O_DEPS: USE_TEST;
 				*test |= PackageTest::DEPS;
 				break;
+			case O_AVAILABLE_DEPEND: USE_TEST;
+				*test |= PackageTest::DEPENDA;
+				break;
+			case O_AVAILABLE_RDEPEND: USE_TEST;
+				*test |= PackageTest::RDEPENDA;
+				break;
+			case O_AVAILABLE_PDEPEND: USE_TEST;
+				*test |= PackageTest::PDEPENDA;
+				break;
+			case O_AVAILABLE_BDEPEND: USE_TEST;
+				*test |= PackageTest::BDEPENDA;
+				break;
+			case O_AVAILABLE_DEPS: USE_TEST;
+				*test |= PackageTest::DEPSA;
+				break;
+			case O_INSTALLED_DEPEND: USE_TEST;
+				*test |= PackageTest::DEPENDI;
+				break;
+			case O_INSTALLED_RDEPEND: USE_TEST;
+				*test |= PackageTest::RDEPENDI;
+				break;
+			case O_INSTALLED_PDEPEND: USE_TEST;
+				*test |= PackageTest::PDEPENDI;
+				break;
+			case O_INSTALLED_BDEPEND: USE_TEST;
+				*test |= PackageTest::BDEPENDI;
+				break;
+			case O_INSTALLED_DEPS: USE_TEST;
+				*test |= PackageTest::DEPSI;
+				break;
 			case O_SEARCH_SET: USE_TEST;
 				*test |= PackageTest::SET;
 				break;
+			case O_SEARCH_SRC_URI: USE_TEST;
+				*test |= PackageTest::SRC_URI;
+				break;
 			case O_SEARCH_EAPI: USE_TEST;
 				*test |= PackageTest::EAPI;
 				break;
